jaclearn.nlp.graph.dependency\_visualizer.render
================================================

.. automodule:: jaclearn.nlp.graph.dependency_visualizer.render

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      DependencyVisualizer
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      visualize_list
      visualize_simple_svg
   
   

   
   
   








.. rubric:: Class DependencyVisualizer
.. autoclass:: DependencyVisualizer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: visualize_list

.. autofunction:: visualize_simple_svg


